@@ -669,7 +669,7 @@ mem_seg (GTopProcMapRow **rs)
 }
 
 static gpointer
-mem_graph_data_fn (Graph *graph, GraphCmd cmd, gpointer data)
+mem_graph_data_fn (Graph *graph, GraphCmd cmd, gpointer data, gint64 *ret)
 {
 	GTopProcViewData *d = (GTopProcViewData *) graph->user_data;
 	GTopProcViewDetails *dt = &d->details;
@@ -683,7 +683,11 @@ mem_graph_data_fn (Graph *graph, GraphCmd cmd, gpointer data)
 	case GRAPH_NEXT:
 		return (*(rs+1)) ? rs+1 : NULL;
 	case GRAPH_VALUE:
-		return (gpointer)((*rs)->VMend - (*rs)->VMstart);
+		if (ret) {
+			*ret = (*rs)->VMend - (*rs)->VMstart;
+			return ret;
+		}
+		return NULL;
 	case GRAPH_LABEL:
 		if ((*rs)->filename) {
 			fname = strrchr ((*rs)->filename, '/');
