@@ -16,7 +16,7 @@ typedef struct _proc_t proc_t;
 struct _proc_t
 {
 	long pid, pcpu, pmem;
-	long hz, stime, utime, cutime, cstime, start_time;
+	long frequency, stime, utime, cutime, cstime, start_time;
 	long size, rss, resident, nice, priority, share;
 	char *user, *cmd, state;
 };
