@@ -4,9 +4,9 @@
 #include "fromtop.h"
 
 void
-sprint_time (char *s, time_t ti, unsigned long hz)
+sprint_time (char *s, time_t ti, unsigned long frequency)
 {
-	time_t t = ti / hz;
+	time_t t = ti / frequency;
 	time_t centi_sec = (ti % 100) * 100 / 100;
 
 	if (t < 0)                            /* time overflow */
