@@ -20,7 +20,8 @@ typedef struct _FsUsageProcInfo		FsUsageProcInfo;
 
 struct _FsUsageProcInfo {
 	char          *cmd;
-	unsigned long  value, percent;
+	unsigned long  percent;
+	gint64         value;
 };
 
 static glibtop_mountentry *mount_list = NULL;
@@ -32,7 +33,7 @@ static void	fsusage_properties_update (GnomePropertyObject *);
 static void	fsusage_properties_load (GnomePropertyObject *);
 static void	fsusage_properties_save (GnomePropertyObject *);
 
-static gpointer	fsusage_data_fn (Graph *, GraphCmd, gpointer);
+static gpointer fsusage_data_fn (Graph *, GraphCmd, gpointer, gint64 *);
 
 #define GTOP_NUM_FSTYPES	7
 
@@ -163,7 +164,7 @@ fsusage_type_set (GTopFsUsageData *d, gint ftype)
 }
 
 static gpointer
-fsusage_data_fn (Graph *graph, GraphCmd cmd, gpointer data)
+fsusage_data_fn (Graph *graph, GraphCmd cmd, gpointer data, gint64 *ret)
 {
 	FsUsageProcInfo *info = data;
 	GTopFsUsageData *d = (GTopFsUsageData *) graph->user_data;
@@ -176,7 +177,7 @@ fsusage_data_fn (Graph *graph, GraphCmd cmd, gpointer data)
 	case GRAPH_FIRST:
 
 		return (fsusage_data) ? (fsusage_data [0].cmd) ?
-			fsusage_data : NULL : NULL;
+			fsusage_data : 0 : 0;
 
 	case GRAPH_NEXT:
 
@@ -184,18 +185,23 @@ fsusage_data_fn (Graph *graph, GraphCmd cmd, gpointer data)
 
 	case GRAPH_VALUE:
 
-		return (gpointer)(info->value);
+		if (ret) {
+			*ret = info->value;
+			return ret;
+		}
+
+		break;
 
 	case GRAPH_LABEL:
 
 		switch (fsmode) {
 		case GTOP_FSMODE_SUBLOCKS:
 		case GTOP_FSMODE_BLOCKS:
-			sprintf (buf, "%s (%3ld%% free) : %8ldk",
+			sprintf (buf, "%s (%3ld%% free) : %8Ldk",
 				 info->cmd, info->percent, info->value);
 			break;
 		case GTOP_FSMODE_INODES:
-			sprintf (buf, "%s (%3ld%% free) : %8ld ",
+			sprintf (buf, "%s (%3ld%% free) : %8Ld ",
 				 info->cmd, info->percent, info->value);
 			break;
 		}
@@ -212,10 +218,9 @@ fsusage_data_fn (Graph *graph, GraphCmd cmd, gpointer data)
 
 		return d->graph_tail ? tail : NULL;
 
-	default:
-
-		return NULL;
 	}
+
+	return NULL;
 }
 
 static int
