@@ -1,5 +1,5 @@
 #include <config.h>
-
+#include <gnome.h>
 #include <global.h>
 
 #include <properties.h>
@@ -76,18 +76,19 @@ radio_mdi_cb (GtkWidget *widget, RadioButtonCbData *cb_data)
 static GtkWidget *
 global_properties_init (GnomePropertyObject *object)
 {
-	GtkWidget *vb, *frame, *button, *table, *label, *spin;
+	GtkWidget *vb, *hb, *frame, *button, *table, *label, *spin;
 	GTopGlobalProperties *prop_ptr = &gtop_properties.global;
 	RadioButtonCbData *cb_data;
 	GtkObject *adjustment;
 	GSList *group;
 
-	vb = gtk_vbox_new (FALSE, 0);
+
+	vb = gtk_vbox_new (0, FALSE);
 	gtk_container_border_width (GTK_CONTAINER (vb), GNOME_PAD_SMALL);
 
 	frame = gtk_frame_new (_("Session management"));
-	table = gtk_table_new (1, 1, TRUE);
-	gtk_table_set_col_spacings (GTK_TABLE (table), GNOME_PAD << 2);
+	table = gtk_table_new (1, 1, FALSE);
+	gtk_table_set_col_spacings (GTK_TABLE (table), GNOME_PAD);
 
 	button = gtk_check_button_new_with_label (_("Always save session"));
 	if (prop_ptr->save_session)
@@ -106,14 +107,14 @@ global_properties_init (GnomePropertyObject *object)
 	gtk_box_pack_start (GTK_BOX (vb), frame, FALSE, TRUE, 0);
 
 	frame = gtk_frame_new (_("Update times (notebook pages)"));
-	table = gtk_table_new (3, 5, TRUE);
+	table = gtk_table_new (3, 3, FALSE);
 	gtk_container_border_width (GTK_CONTAINER (table), GNOME_PAD);
 	gtk_table_set_row_spacings (GTK_TABLE (table), GNOME_PAD_SMALL);
-	gtk_table_set_col_spacings (GTK_TABLE (table), GNOME_PAD << 2);
+	gtk_table_set_col_spacings (GTK_TABLE (table), GNOME_PAD);
 
 	label = gtk_label_new (_("Process List"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-	gtk_table_attach_defaults (GTK_TABLE (table), label, 1, 2, 0, 1);
+	gtk_table_attach_defaults (GTK_TABLE (table), label, 0, 1, 0, 1);
 
 	spin = gtk_spin_button_new (NULL, 1, 0);
 	adjustment = gtk_adjustment_new (1, 1, INT_MAX, 1, 100, 100);
@@ -122,7 +123,7 @@ global_properties_init (GnomePropertyObject *object)
 	gtk_spin_button_set_value
 		(GTK_SPIN_BUTTON (spin),
 		 prop_ptr->update_times [GTOP_UPDATE_PROCVIEW]);
-	gtk_table_attach_defaults (GTK_TABLE (table), spin, 3, 4, 0, 1);
+	gtk_table_attach_defaults (GTK_TABLE (table), spin, 1, 2, 0, 1);
 
 	gtk_signal_connect
 		(GTK_OBJECT (adjustment), "value_changed",
@@ -130,13 +131,13 @@ global_properties_init (GnomePropertyObject *object)
 
 	adjustments [GTOP_UPDATE_PROCVIEW] = GTK_ADJUSTMENT (adjustment);
 
-	label = gtk_label_new (_("milliseconds"));
+	label = gtk_label_new (_("ms"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-	gtk_table_attach_defaults (GTK_TABLE (table), label, 4, 5, 0, 1);
+	gtk_table_attach_defaults (GTK_TABLE (table), label, 2, 3, 0, 1);
 
 	label = gtk_label_new (_("Memory Usage"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-	gtk_table_attach_defaults (GTK_TABLE (table), label, 1, 2, 1, 2);
+	gtk_table_attach_defaults (GTK_TABLE (table), label, 0, 1, 1, 2);
 
 	spin = gtk_spin_button_new (NULL, 1, 0);
 	adjustment = gtk_adjustment_new (1, 1, INT_MAX, 1, 100, 100);
@@ -145,7 +146,7 @@ global_properties_init (GnomePropertyObject *object)
 	gtk_spin_button_set_value
 		(GTK_SPIN_BUTTON (spin),
 		 prop_ptr->update_times [GTOP_UPDATE_MEMUSAGE]);
-	gtk_table_attach_defaults (GTK_TABLE (table), spin, 3, 4, 1, 2);
+	gtk_table_attach_defaults (GTK_TABLE (table), spin, 1, 2, 1, 2);
 
 	gtk_signal_connect
 		(GTK_OBJECT (adjustment), "value_changed",
@@ -153,13 +154,13 @@ global_properties_init (GnomePropertyObject *object)
 
 	adjustments [GTOP_UPDATE_MEMUSAGE] = GTK_ADJUSTMENT (adjustment);
 
-	label = gtk_label_new (_("milliseconds"));
+	label = gtk_label_new (_("ms"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-	gtk_table_attach_defaults (GTK_TABLE (table), label, 4, 5, 1, 2);
+	gtk_table_attach_defaults (GTK_TABLE (table), label, 2, 3, 1, 2);
 
 	label = gtk_label_new (_("Filesystem Usage"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-	gtk_table_attach_defaults (GTK_TABLE (table), label, 1, 2, 2, 3);
+	gtk_table_attach_defaults (GTK_TABLE (table), label, 0, 1, 2, 3);
 
 	spin = gtk_spin_button_new (NULL, 1, 0);
 	adjustment = gtk_adjustment_new (1, 1, INT_MAX, 1, 100, 100);
@@ -168,7 +169,7 @@ global_properties_init (GnomePropertyObject *object)
 	gtk_spin_button_set_value
 		(GTK_SPIN_BUTTON (spin),
 		 prop_ptr->update_times [GTOP_UPDATE_FSUSAGE]);
-	gtk_table_attach_defaults (GTK_TABLE (table), spin, 3, 4, 2, 3);
+	gtk_table_attach_defaults (GTK_TABLE (table), spin, 1, 2, 2, 3);
 
 	gtk_signal_connect
 		(GTK_OBJECT (adjustment), "value_changed",
@@ -176,22 +177,23 @@ global_properties_init (GnomePropertyObject *object)
 
 	adjustments [GTOP_UPDATE_FSUSAGE] = GTK_ADJUSTMENT (adjustment);
 
-	label = gtk_label_new (_("milliseconds"));
+	label = gtk_label_new (_("ms"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-	gtk_table_attach_defaults (GTK_TABLE (table), label, 4, 5, 2, 3);
+	gtk_table_attach_defaults (GTK_TABLE (table), label, 2, 3, 2, 3);
 
 	gtk_container_add (GTK_CONTAINER (frame), table);
-	gtk_box_pack_start (GTK_BOX (vb), frame, FALSE, TRUE, 0);
+	hb = gtk_hbox_new (FALSE, GNOME_PAD_SMALL);
+	gtk_box_pack_start (GTK_BOX (hb), frame, TRUE, TRUE, 0);
 
 	frame = gtk_frame_new (_("Update times (graphical summary)"));
-	table = gtk_table_new (3, 5, TRUE);
+	table = gtk_table_new (3, 3, FALSE);
 	gtk_container_border_width (GTK_CONTAINER (table), GNOME_PAD);
 	gtk_table_set_row_spacings (GTK_TABLE (table), GNOME_PAD_SMALL);
-	gtk_table_set_col_spacings (GTK_TABLE (table), GNOME_PAD << 2);
+	gtk_table_set_col_spacings (GTK_TABLE (table), GNOME_PAD);
 
 	label = gtk_label_new (_("Summary CPU"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-	gtk_table_attach_defaults (GTK_TABLE (table), label, 1, 2, 0, 1);
+	gtk_table_attach_defaults (GTK_TABLE (table), label, 0, 1, 0, 1);
 
 	spin = gtk_spin_button_new (NULL, 1, 0);
 	adjustment = gtk_adjustment_new (1, 1, INT_MAX, 1, 100, 100);
@@ -200,7 +202,7 @@ global_properties_init (GnomePropertyObject *object)
 	gtk_spin_button_set_value
 		(GTK_SPIN_BUTTON (spin),
 		 prop_ptr->update_times [GTOP_UPDATE_CPU]);
-	gtk_table_attach_defaults (GTK_TABLE (table), spin, 3, 4, 0, 1);
+	gtk_table_attach_defaults (GTK_TABLE (table), spin, 1, 2, 0, 1);
 
 	gtk_signal_connect
 		(GTK_OBJECT (adjustment), "value_changed",
@@ -208,13 +210,13 @@ global_properties_init (GnomePropertyObject *object)
 
 	adjustments [GTOP_UPDATE_CPU] = GTK_ADJUSTMENT (adjustment);
 
-	label = gtk_label_new (_("milliseconds"));
+	label = gtk_label_new (_("ms"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-	gtk_table_attach_defaults (GTK_TABLE (table), label, 4, 5, 0, 1);
+	gtk_table_attach_defaults (GTK_TABLE (table), label, 2, 3, 0, 1);
 
 	label = gtk_label_new (_("Summary Mem and Swap"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-	gtk_table_attach_defaults (GTK_TABLE (table), label, 1, 2, 1, 2);
+	gtk_table_attach_defaults (GTK_TABLE (table), label, 0, 1, 1, 2);
 
 	spin = gtk_spin_button_new (NULL, 1, 0);
 	adjustment = gtk_adjustment_new (1, 1, INT_MAX, 1, 100, 100);
@@ -223,7 +225,7 @@ global_properties_init (GnomePropertyObject *object)
 	gtk_spin_button_set_value
 		(GTK_SPIN_BUTTON (spin),
 		 prop_ptr->update_times [GTOP_UPDATE_MEM]);
-	gtk_table_attach_defaults (GTK_TABLE (table), spin, 3, 4, 1, 2);
+	gtk_table_attach_defaults (GTK_TABLE (table), spin, 1, 2, 1, 2);
 
 	gtk_signal_connect
 		(GTK_OBJECT (adjustment), "value_changed",
@@ -231,13 +233,13 @@ global_properties_init (GnomePropertyObject *object)
 
 	adjustments [GTOP_UPDATE_MEM] = GTK_ADJUSTMENT (adjustment);
 
-	label = gtk_label_new (_("milliseconds"));
+	label = gtk_label_new (_("ms"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-	gtk_table_attach_defaults (GTK_TABLE (table), label, 4, 5, 1, 2);
+	gtk_table_attach_defaults (GTK_TABLE (table), label, 2, 3, 1, 2);
 
 	label = gtk_label_new (_("Load Average"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-	gtk_table_attach_defaults (GTK_TABLE (table), label, 1, 2, 2, 3);
+	gtk_table_attach_defaults (GTK_TABLE (table), label, 0, 1, 2, 3);
 
 	spin = gtk_spin_button_new (NULL, 1, 0);
 	adjustment = gtk_adjustment_new (1, 1, INT_MAX, 1, 100, 100);
@@ -246,7 +248,7 @@ global_properties_init (GnomePropertyObject *object)
 	gtk_spin_button_set_value
 		(GTK_SPIN_BUTTON (spin),
 		 prop_ptr->update_times [GTOP_UPDATE_LOAD]);
-	gtk_table_attach_defaults (GTK_TABLE (table), spin, 3, 4, 2, 3);
+	gtk_table_attach_defaults (GTK_TABLE (table), spin, 1, 2, 2, 3);
 
 	gtk_signal_connect
 		(GTK_OBJECT (adjustment), "value_changed",
@@ -254,22 +256,23 @@ global_properties_init (GnomePropertyObject *object)
 
 	adjustments [GTOP_UPDATE_LOAD] = GTK_ADJUSTMENT (adjustment);
 
-	label = gtk_label_new (_("milliseconds"));
+	label = gtk_label_new (_("ms"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-	gtk_table_attach_defaults (GTK_TABLE (table), label, 4, 5, 2, 3);
+	gtk_table_attach_defaults (GTK_TABLE (table), label, 2, 3, 2, 3);
 
 	gtk_container_add (GTK_CONTAINER (frame), table);
-	gtk_box_pack_start (GTK_BOX (vb), frame, FALSE, TRUE, 0);
+	gtk_box_pack_start (GTK_BOX (hb), frame, TRUE, TRUE, 0);
+	gtk_box_pack_start (GTK_BOX (vb), hb, FALSE, TRUE, 0);
 
 	frame = gtk_frame_new (_("Update times (textual summary)"));
-	table = gtk_table_new (4, 5, TRUE);
+	table = gtk_table_new (4, 5, FALSE);
 	gtk_container_border_width (GTK_CONTAINER (table), GNOME_PAD);
 	gtk_table_set_row_spacings (GTK_TABLE (table), GNOME_PAD_SMALL);
-	gtk_table_set_col_spacings (GTK_TABLE (table), GNOME_PAD << 2);
+	gtk_table_set_col_spacings (GTK_TABLE (table), GNOME_PAD);
 
 	label = gtk_label_new (_("CPU statistics"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-	gtk_table_attach_defaults (GTK_TABLE (table), label, 1, 2, 0, 1);
+	gtk_table_attach_defaults (GTK_TABLE (table), label, 0, 1, 0, 1);
 
 	spin = gtk_spin_button_new (NULL, 1, 0);
 	adjustment = gtk_adjustment_new (1, 1, INT_MAX, 1, 100, 100);
@@ -278,7 +281,7 @@ global_properties_init (GnomePropertyObject *object)
 	gtk_spin_button_set_value
 		(GTK_SPIN_BUTTON (spin),
 		 prop_ptr->update_times [GTOP_UPDATE_STATUS_CPU]);
-	gtk_table_attach_defaults (GTK_TABLE (table), spin, 3, 4, 0, 1);
+	gtk_table_attach_defaults (GTK_TABLE (table), spin, 1, 2, 0, 1);
 
 	gtk_signal_connect
 		(GTK_OBJECT (adjustment), "value_changed",
@@ -286,13 +289,13 @@ global_properties_init (GnomePropertyObject *object)
 
 	adjustments [GTOP_UPDATE_STATUS_CPU] = GTK_ADJUSTMENT (adjustment);
 
-	label = gtk_label_new (_("milliseconds"));
+	label = gtk_label_new (_("ms"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-	gtk_table_attach_defaults (GTK_TABLE (table), label, 4, 5, 0, 1);
+	gtk_table_attach_defaults (GTK_TABLE (table), label, 2, 3, 0, 1);
 
 	label = gtk_label_new (_("Memory statistics"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-	gtk_table_attach_defaults (GTK_TABLE (table), label, 1, 2, 1, 2);
+	gtk_table_attach_defaults (GTK_TABLE (table), label, 0, 1, 1, 2);
 
 	spin = gtk_spin_button_new (NULL, 1, 0);
 	adjustment = gtk_adjustment_new (1, 1, INT_MAX, 1, 100, 100);
@@ -301,7 +304,7 @@ global_properties_init (GnomePropertyObject *object)
 	gtk_spin_button_set_value
 		(GTK_SPIN_BUTTON (spin),
 		 prop_ptr->update_times [GTOP_UPDATE_STATUS_MEMORY]);
-	gtk_table_attach_defaults (GTK_TABLE (table), spin, 3, 4, 1, 2);
+	gtk_table_attach_defaults (GTK_TABLE (table), spin, 1, 2, 1, 2);
 
 	gtk_signal_connect
 		(GTK_OBJECT (adjustment), "value_changed",
@@ -309,13 +312,13 @@ global_properties_init (GnomePropertyObject *object)
 
 	adjustments [GTOP_UPDATE_STATUS_MEMORY] = GTK_ADJUSTMENT (adjustment);
 
-	label = gtk_label_new (_("milliseconds"));
+	label = gtk_label_new (_("ms"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-	gtk_table_attach_defaults (GTK_TABLE (table), label, 4, 5, 1, 2);
+	gtk_table_attach_defaults (GTK_TABLE (table), label, 2, 3, 1, 2);
 
 	label = gtk_label_new (_("Uptime"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-	gtk_table_attach_defaults (GTK_TABLE (table), label, 1, 2, 2, 3);
+	gtk_table_attach_defaults (GTK_TABLE (table), label, 0, 1, 2, 3);
 
 	spin = gtk_spin_button_new (NULL, 1, 0);
 	adjustment = gtk_adjustment_new (1, 1, INT_MAX, 1, 100, 100);
@@ -324,7 +327,7 @@ global_properties_init (GnomePropertyObject *object)
 	gtk_spin_button_set_value
 		(GTK_SPIN_BUTTON (spin),
 		 prop_ptr->update_times [GTOP_UPDATE_STATUS_UPTIME]);
-	gtk_table_attach_defaults (GTK_TABLE (table), spin, 3, 4, 2, 3);
+	gtk_table_attach_defaults (GTK_TABLE (table), spin, 1, 2, 2, 3);
 
 	gtk_signal_connect
 		(GTK_OBJECT (adjustment), "value_changed",
@@ -332,13 +335,13 @@ global_properties_init (GnomePropertyObject *object)
 
 	adjustments [GTOP_UPDATE_STATUS_UPTIME] = GTK_ADJUSTMENT (adjustment);
 
-	label = gtk_label_new (_("milliseconds"));
+	label = gtk_label_new (_("ms"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-	gtk_table_attach_defaults (GTK_TABLE (table), label, 4, 5, 2, 3);
+	gtk_table_attach_defaults (GTK_TABLE (table), label, 2, 3, 2, 3);
 
 	label = gtk_label_new (_("Load average"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-	gtk_table_attach_defaults (GTK_TABLE (table), label, 1, 2, 3, 4);
+	gtk_table_attach_defaults (GTK_TABLE (table), label, 0, 1, 3, 4);
 
 	spin = gtk_spin_button_new (NULL, 1, 0);
 	adjustment = gtk_adjustment_new (1, 1, INT_MAX, 1, 100, 100);
@@ -347,7 +350,7 @@ global_properties_init (GnomePropertyObject *object)
 	gtk_spin_button_set_value
 		(GTK_SPIN_BUTTON (spin),
 		 prop_ptr->update_times [GTOP_UPDATE_STATUS_LOADAVG]);
-	gtk_table_attach_defaults (GTK_TABLE (table), spin, 3, 4, 3, 4);
+	gtk_table_attach_defaults (GTK_TABLE (table), spin, 1, 2, 3, 4);
 
 	gtk_signal_connect
 		(GTK_OBJECT (adjustment), "value_changed",
@@ -355,16 +358,17 @@ global_properties_init (GnomePropertyObject *object)
 
 	adjustments [GTOP_UPDATE_STATUS_LOADAVG] = GTK_ADJUSTMENT (adjustment);
 
-	label = gtk_label_new (_("milliseconds"));
+	label = gtk_label_new (_("ms"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-	gtk_table_attach_defaults (GTK_TABLE (table), label, 4, 5, 3, 4);
+	gtk_table_attach_defaults (GTK_TABLE (table), label, 2, 3, 3, 4);
 
 	gtk_container_add (GTK_CONTAINER (frame), table);
-	gtk_box_pack_start (GTK_BOX (vb), frame, FALSE, TRUE, 0);
+	hb = gtk_hbox_new (FALSE, GNOME_PAD_SMALL);
+	gtk_box_pack_start (GTK_BOX (hb), frame, TRUE, TRUE, 0);
 
 	frame = gtk_frame_new (_("MDI Mode"));
-	table = gtk_table_new (3, 3, TRUE);
-	gtk_table_set_col_spacings (GTK_TABLE (table), GNOME_PAD << 2);
+	table = gtk_table_new (3, 4, FALSE);
+	gtk_table_set_col_spacings (GTK_TABLE (table), GNOME_PAD);
 
 	button = gtk_radio_button_new_with_label (NULL, _("Notebook"));
 	if (prop_ptr->mdi_mode == GNOME_MDI_NOTEBOOK)
@@ -377,7 +381,8 @@ global_properties_init (GnomePropertyObject *object)
 
 	gtk_signal_connect
 		(GTK_OBJECT (button), "toggled", radio_mdi_cb, cb_data);
-	gtk_table_attach_defaults (GTK_TABLE (table), button, 1, 2, 0, 1);
+	gtk_table_attach (GTK_TABLE (table), button, 1, 2, 0, 1,
+			  GTK_EXPAND | GTK_FILL, GTK_FILL, 0, 0);
 
 	group = gtk_radio_button_group (GTK_RADIO_BUTTON (button));
 	button = gtk_radio_button_new_with_label (group, _("Toplevel"));
@@ -391,7 +396,8 @@ global_properties_init (GnomePropertyObject *object)
 
 	gtk_signal_connect
 		(GTK_OBJECT (button), "toggled", radio_mdi_cb, cb_data);
-	gtk_table_attach_defaults (GTK_TABLE (table), button, 1, 2, 1, 2);
+	gtk_table_attach (GTK_TABLE (table), button, 1, 2, 1, 2,
+			  GTK_EXPAND | GTK_FILL, GTK_FILL, 0, 0);
 
 	group = gtk_radio_button_group (GTK_RADIO_BUTTON (button));
 	button = gtk_radio_button_new_with_label (group, _("Modal"));
@@ -405,10 +411,12 @@ global_properties_init (GnomePropertyObject *object)
 
 	gtk_signal_connect
 		(GTK_OBJECT (button), "toggled", radio_mdi_cb, cb_data);
-	gtk_table_attach_defaults (GTK_TABLE (table), button, 1, 2, 2, 3);
+	gtk_table_attach (GTK_TABLE (table), button, 1, 2, 2, 3,
+			  GTK_EXPAND | GTK_FILL, GTK_FILL, 0, 0);
 
 	gtk_container_add (GTK_CONTAINER (frame), table);
-	gtk_box_pack_start (GTK_BOX (vb), frame, FALSE, TRUE, 0);
+	gtk_box_pack_start (GTK_BOX (hb), frame, TRUE, TRUE, 0);
+	gtk_box_pack_start (GTK_BOX (vb), hb, FALSE, TRUE, 0);
 
 	return vb;
 }
