@@ -227,8 +227,8 @@ graph_process_data (Graph *g)
 	fh = (graph_font->ascent + graph_font->descent);
 	asc2 = (th >> 1) - (th&1);
 	
-	head = g->data_fn (g, GRAPH_HEAD, NULL);
-	tail = g->data_fn (g, GRAPH_TAIL, NULL);
+	head = g->data_fn (g, GRAPH_HEAD, NULL, NULL);
+	tail = g->data_fn (g, GRAPH_TAIL, NULL, NULL);
 
 	/*
 	 * two passes
@@ -297,15 +297,17 @@ graph_process_data (Graph *g)
 
 		}
 
-		data = g->data_fn (g, GRAPH_FIRST, NULL);
+		data = g->data_fn (g, GRAPH_FIRST, NULL, NULL);
 
 		while (data) {
-			gchar *label = g->data_fn (g, GRAPH_LABEL, data);
-			value = (unsigned) GPOINTER_TO_UINT
-			  (g->data_fn (g, GRAPH_VALUE, data));
+			gchar *label = g->data_fn
+				(g, GRAPH_LABEL, data, NULL);
+			gint64 value = 0;
+
+			g->data_fn (g, GRAPH_VALUE, data, &value);
 			if (total == 0) total = 1; /* avoids division by 0. */
 
-			data = g->data_fn (g, GRAPH_NEXT, data);
+			data = g->data_fn (g, GRAPH_NEXT, data, NULL);
 
 			if (draw) {
 				double idx = (double)value / total;
