@@ -23,7 +23,7 @@ typedef enum _GraphCmd GraphCmd;
 
 typedef struct _Graph Graph;
 
-typedef gpointer (*GraphDataFunc) (Graph *, GraphCmd, gpointer);
+typedef gpointer (*GraphDataFunc) (Graph *, GraphCmd, gpointer, gint64 *);
 
 struct _Graph {
 	GtkWidget *da;
