@@ -332,10 +332,11 @@ gtop_procview_size_request (GtkWidget *widget, GtkRequisition *requisition)
 	requisition->height = GTK_CONTAINER (widget)->border_width * 2;
 
 	if (bin->child && GTK_WIDGET_VISIBLE (bin->child)) {
-		gtk_widget_size_request (bin->child, &bin->child->requisition);
+		GtkRequisition child_requisition;
+		gtk_widget_size_request (bin->child, &child_requisition);
 
-		requisition->width += bin->child->requisition.width;
-		requisition->height += bin->child->requisition.height;
+		requisition->width += child_requisition.width;
+		requisition->height += child_requisition.height;
 	}
 }
 
