@@ -162,6 +162,10 @@ main (int argc, char *argv[])
 	gtop_parse_args ();
 
 	poptFreeContext (ctx);
+
+	/* Initialize LibGTop. */
+
+	gtop_init_libgtop ();
 	
 	/* session management init */
         client = gnome_master_client ();
