@@ -21,13 +21,14 @@ typedef struct _MemUsageProcInfo MemUsageProcInfo;
 struct _MemUsageProcInfo {
 	char          *cmd;
 	gint           n;
-	unsigned long  value;
+	gint64         value;
 };
 
 
 static GtkAdjustment *adjustments [MEMUSAGE_FIELDS];
 
-static gpointer	memusage_data_fn (Graph *, GraphCmd, gpointer);
+static gpointer
+ memusage_data_fn (Graph *, GraphCmd, gpointer, gint64 *);
 
 static unsigned *proc_tab = NULL;
 static int memusage_data_count = 0;
@@ -113,7 +114,7 @@ memusage_type_set (GTopMemUsageData *d, gint ftype)
 }
 
 static gpointer
-memusage_data_fn (Graph *graph, GraphCmd cmd, gpointer data)
+memusage_data_fn (Graph *graph, GraphCmd cmd, gpointer data, gint64 *ret)
 {
 	MemUsageProcInfo *info = data;
 	GTopMemUsageData *d = (GTopMemUsageData *) graph->user_data;
@@ -125,7 +126,7 @@ memusage_data_fn (Graph *graph, GraphCmd cmd, gpointer data)
 	case GRAPH_FIRST:
 
 		return (memusage_data) ? (memusage_data [0].cmd) ?
-			memusage_data : NULL : NULL;
+			memusage_data : 0 : 0;
 
 	case GRAPH_NEXT:
 
@@ -133,15 +134,20 @@ memusage_data_fn (Graph *graph, GraphCmd cmd, gpointer data)
 
 	case GRAPH_VALUE:
 
-		return (gpointer)(info->value);
+		if (ret) {
+			*ret = info->value;
+			return ret;
+		}
+
+		break;
 
 	case GRAPH_LABEL:
 
 		if (info->n > 1)
-			sprintf (buf, "%s (%2d) : %8ldk",
+			sprintf (buf, "%s (%2d) : %8Ldk",
 				 info->cmd, info->n, info->value);
 		else
-			sprintf (buf, "%s      : %8ldk",
+			sprintf (buf, "%s      : %8Ldk",
 				 info->cmd, info->value);
 
 		return buf;
@@ -156,10 +162,9 @@ memusage_data_fn (Graph *graph, GraphCmd cmd, gpointer data)
 
 		return tail;
 
-	default:
-
-		return NULL;
 	}
+
+	return NULL;
 }
 
 static int
