@@ -950,6 +950,8 @@ procview_update (GTopProcViewData *d)
 
 	glibtop_get_mem (&mem);
 	p_gl_main_mem = mem.total >> 10;
+	/* avoid divison by zero later. */
+	if (!p_gl_main_mem) p_gl_main_mem = 1;
 
 	switch (d->ftype) {
 	case GTOP_PROCVIEW_USER:
