@@ -117,7 +117,8 @@ struct _GTopSummaryProperties
 {
 	GdkFont *statusbar_font;
 	gchar *statusbar_font_name;
-	gint summary_mode;
+	glong summary_mode;
+	glong summary_supported;
 	gfloat maximum_loadavg;
 };
 
