@@ -70,10 +70,14 @@ static const GdkColor load_defaults [2] = {
 
 #define SUMMARY_MODE_BIT(bit)	\
 (gtop_properties.summary.summary_mode & (1 << GTOP_SUMMARY_ ## bit))
+#define SUMMARY_SUPPORTED_BIT(bit)	\
+(gtop_properties.summary.summary_supported & (1 << GTOP_SUMMARY_ ## bit))
 #define SUMMARY_GRAPH_BIT(bit)	\
-(SUMMARY_MODE_BIT (SHOW_GRAPH) && SUMMARY_MODE_BIT (bit))
+(SUMMARY_MODE_BIT (SHOW_GRAPH) && SUMMARY_MODE_BIT (bit) && \
+ SUMMARY_SUPPORTED_BIT (bit))
 #define SUMMARY_TEXT_BIT(bit)	\
-(SUMMARY_MODE_BIT (SHOW_TEXT) && SUMMARY_MODE_BIT (bit))
+(SUMMARY_MODE_BIT (SHOW_TEXT) && SUMMARY_MODE_BIT (bit) && \
+ SUMMARY_SUPPORTED_BIT (bit))
 #define PIX(x) widget = gnome_pixmap_new_from_xpm_d (x ## _xpm); \
                         gtk_widget_ref (widget);
                
@@ -120,6 +124,59 @@ GnomePropertyDescriptor SummaryProperty_Descriptor = {
 static GList *statusbar_object_list = NULL;
 static GList *summary_object_list = NULL;
 
+static void
+summary_check_libgtop_support ()
+{
+	/* This things are always supported. */
+	glong summary_supported = (1 << GTOP_SUMMARY_TEXT_STATUSBAR) |
+		(1 << GTOP_SUMMARY_TEXT_HOSTNAME) |
+		(1 << GTOP_SUMMARY_TEXT_USE_FQDN);
+
+	/* Check whether LibGTop has all the required features. */
+	if (!gtop_libgtop_is_summary_supported (GTOP_SUMMARY_TEXT_CPU))
+		summary_supported |= (1 << GTOP_SUMMARY_TEXT_CPU);
+
+	if (!gtop_libgtop_is_summary_supported (GTOP_SUMMARY_TEXT_MEMORY))
+		summary_supported |= (1 << GTOP_SUMMARY_TEXT_MEMORY);
+
+	if (!gtop_libgtop_is_summary_supported (GTOP_SUMMARY_TEXT_MEMORY))
+		summary_supported |= (1 << GTOP_SUMMARY_TEXT_MEMORY);
+
+	if (!gtop_libgtop_is_summary_supported (GTOP_SUMMARY_TEXT_SWAP))
+		summary_supported |= (1 << GTOP_SUMMARY_TEXT_SWAP);
+
+	if (!gtop_libgtop_is_summary_supported (GTOP_SUMMARY_TEXT_UPTIME))
+		summary_supported |= (1 << GTOP_SUMMARY_TEXT_UPTIME);
+
+	if (!gtop_libgtop_is_summary_supported (GTOP_SUMMARY_TEXT_LOADAVG))
+		summary_supported |= (1 << GTOP_SUMMARY_TEXT_LOADAVG);
+
+	if (!gtop_libgtop_is_summary_supported (GTOP_SUMMARY_GRAPH_CPU))
+		summary_supported |= (1 << GTOP_SUMMARY_GRAPH_CPU);
+
+	if (!gtop_libgtop_is_summary_supported (GTOP_SUMMARY_GRAPH_XCPU))
+		summary_supported |= (1 << GTOP_SUMMARY_GRAPH_XCPU);
+
+	if (!gtop_libgtop_is_summary_supported (GTOP_SUMMARY_GRAPH_MEM))
+		summary_supported |= (1 << GTOP_SUMMARY_GRAPH_MEM);
+
+	if (!gtop_libgtop_is_summary_supported (GTOP_SUMMARY_GRAPH_SWAP))
+		summary_supported |= (1 << GTOP_SUMMARY_GRAPH_SWAP);
+
+	if (!gtop_libgtop_is_summary_supported (GTOP_SUMMARY_GRAPH_LOAD))
+		summary_supported |= (1 << GTOP_SUMMARY_GRAPH_LOAD);
+
+	/* Graphical summary is supported if at least one field in it
+	 * is supported. */
+	if (summary_supported &
+	    ((1 << GTOP_SUMMARY_GRAPH_CPU) | (1 << GTOP_SUMMARY_GRAPH_XCPU) |
+	     (1 << GTOP_SUMMARY_GRAPH_MEM) | (1 << GTOP_SUMMARY_GRAPH_SWAP) |
+	     (1 << GTOP_SUMMARY_GRAPH_LOAD)))
+		summary_supported |= (1 << GTOP_SUMMARY_SHOW_GRAPH);
+
+	gtop_properties.summary.summary_supported = summary_supported;
+}
+
 static gint
 summary_cpu (GTopSummaryData *d)
 {
@@ -235,7 +292,8 @@ summary_update (GTopSummaryData *d)
 	gint config_has_swap;
 	gint i;
 
-	if (SUMMARY_MODE_BIT (SHOW_GRAPH))
+	if (SUMMARY_MODE_BIT (SHOW_GRAPH) &&
+	    SUMMARY_SUPPORTED_BIT (SHOW_GRAPH))
 		gtk_widget_show (d->box);
 	else
 		gtk_widget_hide (d->box);
@@ -832,10 +890,12 @@ static GtkWidget *
 summary_properties_init (GnomePropertyObject *object)
 {
 	GTopSummaryProperties *prop_ptr = &gtop_properties.summary;
-	GtkWidget *vb, *hb1, *frame, *label, *entry, *button, *table, *spin, *hb;
+	GtkWidget *vb, *hb1, *frame, *label, *entry;
+	GtkWidget *button, *table, *spin, *hb;
 	RadioButtonCbData *cb_data;
 	GtkObject *adjustment;
-	gint summary_mode;
+	glong summary_mode;
+	glong summary_supported;
 
 	vb    = gtk_vbox_new (FALSE, 0);
 	gtk_container_border_width (GTK_CONTAINER (vb), GNOME_PAD_SMALL);
@@ -857,6 +917,7 @@ summary_properties_init (GnomePropertyObject *object)
 	gtk_container_border_width (GTK_CONTAINER (table), GNOME_PAD_SMALL);
 
 	summary_mode = prop_ptr->summary_mode;
+	summary_supported = prop_ptr->summary_supported;
 
 	label = gtk_check_button_new_with_label (_("Show graphical summary"));
 	if (summary_mode & (1 << GTOP_SUMMARY_SHOW_GRAPH))
@@ -867,6 +928,9 @@ summary_properties_init (GnomePropertyObject *object)
 	cb_data->button = label;
 	cb_data->object = object;
 	
+	if (!(summary_supported & (1 << GTOP_SUMMARY_SHOW_GRAPH)))
+		gtk_widget_set_sensitive (label, FALSE);
+	
 	gtk_signal_connect
 		(GTK_OBJECT (label), "toggled", summary_mode_cb, cb_data);
 	gtk_table_attach (GTK_TABLE (table), label, 0, 3, 0, 1,
@@ -880,6 +944,9 @@ summary_properties_init (GnomePropertyObject *object)
 	cb_data->index = GTOP_SUMMARY_GRAPH_CPU;
 	cb_data->button = label;
 	cb_data->object = object;
+
+	if (!(summary_supported & (1 << GTOP_SUMMARY_GRAPH_CPU)))
+		gtk_widget_set_sensitive (label, FALSE);
 	
 	gtk_signal_connect
 		(GTK_OBJECT (label), "toggled", summary_mode_cb, cb_data);
@@ -895,6 +962,9 @@ summary_properties_init (GnomePropertyObject *object)
 	cb_data->button = label;
 	cb_data->object = object;
 	
+	if (!(summary_supported & (1 << GTOP_SUMMARY_GRAPH_XCPU)))
+		gtk_widget_set_sensitive (label, FALSE);
+	
 	gtk_signal_connect
 		(GTK_OBJECT (label), "toggled", summary_mode_cb, cb_data);
 	gtk_table_attach (GTK_TABLE (table), label, 2, 3, 2, 3,
@@ -909,6 +979,9 @@ summary_properties_init (GnomePropertyObject *object)
 	cb_data->button = label;
 	cb_data->object = object;
 	
+	if (!(summary_supported & (1 << GTOP_SUMMARY_GRAPH_MEM)))
+		gtk_widget_set_sensitive (label, FALSE);
+	
 	gtk_signal_connect
 		(GTK_OBJECT (label), "toggled", summary_mode_cb, cb_data);
 	gtk_table_attach (GTK_TABLE (table), label, 1, 3, 3, 4,
@@ -923,6 +996,9 @@ summary_properties_init (GnomePropertyObject *object)
 	cb_data->button = label;
 	cb_data->object = object;
 	
+	if (!(summary_supported & (1 << GTOP_SUMMARY_GRAPH_SWAP)))
+		gtk_widget_set_sensitive (label, FALSE);
+	
 	gtk_signal_connect
 		(GTK_OBJECT (label), "toggled", summary_mode_cb, cb_data);
 	gtk_table_attach (GTK_TABLE (table), label, 1, 3, 4, 5,
@@ -937,6 +1013,9 @@ summary_properties_init (GnomePropertyObject *object)
 	cb_data->button = label;
 	cb_data->object = object;
 	
+	if (!(summary_supported & (1 << GTOP_SUMMARY_GRAPH_LOAD)))
+		gtk_widget_set_sensitive (label, FALSE);
+	
 	gtk_signal_connect
 		(GTK_OBJECT (label), "toggled", summary_mode_cb, cb_data);
 	gtk_table_attach (GTK_TABLE (table), label, 1, 3, 5, 6,
@@ -952,6 +1031,9 @@ summary_properties_init (GnomePropertyObject *object)
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 	gtk_box_pack_start_defaults (GTK_BOX (hb), label);
 
+	if (!(summary_supported & (1 << GTOP_SUMMARY_GRAPH_LOAD)))
+		gtk_widget_set_sensitive (label, FALSE);
+	
 	spin = gtk_spin_button_new (NULL, 0.1, 1);
 	adjustment = gtk_adjustment_new (1.0, 1.0, 10000.0, 0.1, 1.0, 1.0);
 	gtk_spin_button_set_adjustment
@@ -963,6 +1045,9 @@ summary_properties_init (GnomePropertyObject *object)
 	gtk_table_attach (GTK_TABLE (table), hb, 2, 3, 6, 7,
 			  GTK_EXPAND | GTK_FILL, GTK_FILL, 0, 0);
 
+	if (!(summary_supported & (1 << GTOP_SUMMARY_GRAPH_LOAD)))
+		gtk_widget_set_sensitive (spin, FALSE);
+	
 	gtk_signal_connect
 		(GTK_OBJECT (adjustment), "value_changed",
 		 adjustment_changed_cb, adjustment);
@@ -1037,6 +1122,9 @@ summary_properties_init (GnomePropertyObject *object)
 	cb_data->button = label;
 	cb_data->object = object;
 	
+	if (!(summary_supported & (1 << GTOP_SUMMARY_TEXT_CPU)))
+		gtk_widget_set_sensitive (label, FALSE);
+
 	gtk_signal_connect
 		(GTK_OBJECT (label), "toggled", summary_mode_cb, cb_data);
 	gtk_table_attach_defaults (GTK_TABLE (table), label, 1, 3, 4, 5);
@@ -1050,6 +1138,9 @@ summary_properties_init (GnomePropertyObject *object)
 	cb_data->button = label;
 	cb_data->object = object;
 	
+	if (!(summary_supported & (1 << GTOP_SUMMARY_TEXT_MEMORY)))
+		gtk_widget_set_sensitive (label, FALSE);
+
 	gtk_signal_connect
 		(GTK_OBJECT (label), "toggled", summary_mode_cb, cb_data);
 	gtk_table_attach_defaults (GTK_TABLE (table), label, 1, 3, 5, 6);
@@ -1063,6 +1154,9 @@ summary_properties_init (GnomePropertyObject *object)
 	cb_data->button = label;
 	cb_data->object = object;
 	
+	if (!(summary_supported & (1 << GTOP_SUMMARY_TEXT_SWAP)))
+		gtk_widget_set_sensitive (label, FALSE);
+
 	gtk_signal_connect
 		(GTK_OBJECT (label), "toggled", summary_mode_cb, cb_data);
 	gtk_table_attach_defaults (GTK_TABLE (table), label, 2, 3, 6, 7);
@@ -1076,6 +1170,9 @@ summary_properties_init (GnomePropertyObject *object)
 	cb_data->button = label;
 	cb_data->object = object;
 	
+	if (!(summary_supported & (1 << GTOP_SUMMARY_TEXT_UPTIME)))
+		gtk_widget_set_sensitive (label, FALSE);
+
 	gtk_signal_connect
 		(GTK_OBJECT (label), "toggled", summary_mode_cb, cb_data);
 	gtk_table_attach_defaults (GTK_TABLE (table), label, 1, 3, 7, 8);
@@ -1089,6 +1186,9 @@ summary_properties_init (GnomePropertyObject *object)
 	cb_data->button = label;
 	cb_data->object = object;
 	
+	if (!(summary_supported & (1 << GTOP_SUMMARY_TEXT_LOADAVG)))
+		gtk_widget_set_sensitive (label, FALSE);
+
 	gtk_signal_connect
 		(GTK_OBJECT (label), "toggled", summary_mode_cb, cb_data);
 	gtk_table_attach_defaults (GTK_TABLE (table), label, 1, 3, 8, 9);
@@ -1116,6 +1216,8 @@ summary_properties_load (GnomePropertyObject *object)
 	gtop_properties.summary.summary_mode =
 		gnome_config_get_int ("gtop/procview/summary_mode=30623");
 
+	summary_check_libgtop_support ();
+
 	sprintf (name, "gtop/procview/statusbar_font_name=%s",
 		 STATUSBAR_DEFAULT_FONT);
 	gtop_properties.summary.statusbar_font_name =
